from .structs import Pair

AAVE_BTC = Pair("AAVE_BTC", price_precision=7, quantity_precision=4)
AAVE_USDC = Pair("AAVE_USDC", price_precision=2, quantity_precision=4)
AAVE_USDT = Pair("AAVE_USDT", price_precision=3, quantity_precision=4)
ACA_BTC = Pair("ACA_BTC", price_precision=9, quantity_precision=2)
ACA_USDT = Pair("ACA_USDT", price_precision=4, quantity_precision=2)
ADA_BTC = Pair("ADA_BTC", price_precision=9, quantity_precision=0)
ADA_USDC = Pair("ADA_USDC", price_precision=5, quantity_precision=1)
ADA_USDT = Pair("ADA_USDT", price_precision=5, quantity_precision=1)
AERGO_BTC = Pair("AERGO_BTC", price_precision=10, quantity_precision=1)
AERGO_USDT = Pair("AERGO_USDT", price_precision=5, quantity_precision=1)
AGLD_USDT = Pair("AGLD_USDT", price_precision=4, quantity_precision=2)
AKT_USDT = Pair("AKT_USDT", price_precision=4, quantity_precision=2)
ALGO_BTC = Pair("ALGO_BTC", price_precision=8, quantity_precision=2)
ALGO_USDC = Pair("ALGO_USDC", price_precision=4, quantity_precision=2)
ALGO_USDT = Pair("ALGO_USDT", price_precision=4, quantity_precision=2)
ALICE_BTC = Pair("ALICE_BTC", price_precision=8, quantity_precision=3)
ALICE_USDT = Pair("ALICE_USDT", price_precision=3, quantity_precision=3)
ALI_BTC = Pair("ALI_BTC", price_precision=10, quantity_precision=1)
ALI_USDT = Pair("ALI_USDT", price_precision=6, quantity_precision=0)
ALPHA_USDT = Pair("ALPHA_USDT", price_precision=5, quantity_precision=1)
AMP_USDT = Pair("AMP_USDT", price_precision=5, quantity_precision=1)
ANKR_USDT = Pair("ANKR_USDT", price_precision=6, quantity_precision=1)
APE_BTC = Pair("APE_BTC", price_precision=8, quantity_precision=3)
APE_USDC = Pair("APE_USDC", price_precision=4, quantity_precision=2)
APE_USDT = Pair("APE_USDT", price_precision=4, quantity_precision=2)
API3_BTC = Pair("API3_BTC", price_precision=8, quantity_precision=3)
API3_USDC = Pair("API3_USDC", price_precision=4, quantity_precision=2)
API3_USDT = Pair("API3_USDT", price_precision=4, quantity_precision=2)
ARPA_USDC = Pair("ARPA_USDC", price_precision=5, quantity_precision=1)
AR_USDC = Pair("AR_USDC", price_precision=3, quantity_precision=3)
AR_USDT = Pair("AR_USDT", price_precision=3, quantity_precision=3)
ATOM_BTC = Pair("ATOM_BTC", price_precision=7, quantity_precision=2)
ATOM_CRO = Pair("ATOM_CRO", price_precision=2, quantity_precision=2)
ATOM_USDC = Pair("ATOM_USDC", price_precision=3, quantity_precision=3)
ATOM_USDT = Pair("ATOM_USDT", price_precision=3, quantity_precision=2)
AUDIO_BTC = Pair("AUDIO_BTC", price_precision=9, quantity_precision=2)
AUDIO_USDC = Pair("AUDIO_USDC", price_precision=4, quantity_precision=2)
AUDIO_USDT = Pair("AUDIO_USDT", price_precision=4, quantity_precision=2)
AURORA_USDT = Pair("AURORA_USDT", price_precision=4, quantity_precision=2)
AUTO_USDT = Pair("AUTO_USDT", price_precision=2, quantity_precision=4)
AVAX_BTC = Pair("AVAX_BTC", price_precision=7, quantity_precision=3)
AVAX_USDC = Pair("AVAX_USDC", price_precision=3, quantity_precision=3)
AVAX_USDT = Pair("AVAX_USDT", price_precision=3, quantity_precision=3)
AXS_BTC = Pair("AXS_BTC", price_precision=7, quantity_precision=3)
AXS_USDC = Pair("AXS_USDC", price_precision=3, quantity_precision=3)
AXS_USDT = Pair("AXS_USDT", price_precision=4, quantity_precision=2)
BADGER_USDT = Pair("BADGER_USDT", price_precision=3, quantity_precision=3)
BAL_BTC = Pair("BAL_BTC", price_precision=8, quantity_precision=3)
BAL_USDT = Pair("BAL_USDT", price_precision=3, quantity_precision=3)
BAND_USDT = Pair("BAND_USDT", price_precision=4, quantity_precision=2)
BAT_USDT = Pair("BAT_USDT", price_precision=4, quantity_precision=2)
BCH_BTC = Pair("BCH_BTC", price_precision=6, quantity_precision=3)
BCH_USDT = Pair("BCH_USDT", price_precision=2, quantity_precision=5)
BICO_USDT = Pair("BICO_USDT", price_precision=4, quantity_precision=2)
BIFI_USDT = Pair("BIFI_USDT", price_precision=2, quantity_precision=5)
BNT_USDT = Pair("BNT_USDT", price_precision=4, quantity_precision=3)
BOND_USDC = Pair("BOND_USDC", price_precision=3, quantity_precision=3)
BOND_USDT = Pair("BOND_USDT", price_precision=3, quantity_precision=3)
BOSON_USDT = Pair("BOSON_USDT", price_precision=4, quantity_precision=2)
BRZ_USDT = Pair("BRZ_USDT", price_precision=5, quantity_precision=1)
BTC_USDC = Pair("BTC_USDC", price_precision=2, quantity_precision=6)
BTC_USDT = Pair("BTC_USDT", price_precision=2, quantity_precision=6)
BUSD_USDT = Pair("BUSD_USDT", price_precision=4, quantity_precision=2)
C98_USDT = Pair("C98_USDT", price_precision=4, quantity_precision=2)
CELR_USDC = Pair("CELR_USDC", price_precision=6, quantity_precision=0)
CELR_USDT = Pair("CELR_USDT", price_precision=6, quantity_precision=1)
CHR_BTC = Pair("CHR_BTC", price_precision=10, quantity_precision=1)
CHR_USDT = Pair("CHR_USDT", price_precision=5, quantity_precision=1)
CHZ_BTC = Pair("CHZ_BTC", price_precision=10, quantity_precision=1)
CHZ_USDT = Pair("CHZ_USDT", price_precision=5, quantity_precision=2)
CKB_USDT = Pair("CKB_USDT", price_precision=6, quantity_precision=0)
COMP_BTC = Pair("COMP_BTC", price_precision=7, quantity_precision=4)
COMP_USDT = Pair("COMP_USDT", price_precision=2, quantity_precision=5)
COTI_BTC = Pair("COTI_BTC", price_precision=10, quantity_precision=1)
COTI_USDC = Pair("COTI_USDC", price_precision=5, quantity_precision=1)
COTI_USDT = Pair("COTI_USDT", price_precision=5, quantity_precision=1)
CQT_USDT = Pair("CQT_USDT", price_precision=4, quantity_precision=2)
CRO_BTC = Pair("CRO_BTC", price_precision=9, quantity_precision=2)
CRO_USDC = Pair("CRO_USDC", price_precision=5, quantity_precision=3)
CRO_USDT = Pair("CRO_USDT", price_precision=5, quantity_precision=3)
CRPT_USDT = Pair("CRPT_USDT", price_precision=5, quantity_precision=1)
CRV_BTC = Pair("CRV_BTC", price_precision=8, quantity_precision=2)
CRV_USDC = Pair("CRV_USDC", price_precision=4, quantity_precision=2)
CRV_USDT = Pair("CRV_USDT", price_precision=4, quantity_precision=4)
CSPR_BTC = Pair("CSPR_BTC", price_precision=10, quantity_precision=1)
CSPR_USDT = Pair("CSPR_USDT", price_precision=5, quantity_precision=1)
CTSI_USDT = Pair("CTSI_USDT", price_precision=5, quantity_precision=1)
CVX_USDC = Pair("CVX_USDC", price_precision=3, quantity_precision=3)
CVX_USDT = Pair("CVX_USDT", price_precision=3, quantity_precision=3)
DAI_USDC = Pair("DAI_USDC", price_precision=4, quantity_precision=2)
DAI_USDT = Pair("DAI_USDT", price_precision=4, quantity_precision=3)
DAR_BTC = Pair("DAR_BTC", price_precision=9, quantity_precision=2)
DAR_USDC = Pair("DAR_USDC", price_precision=5, quantity_precision=1)
DAR_USDT = Pair("DAR_USDT", price_precision=4, quantity_precision=2)
DERC_USDC = Pair("DERC_USDC", price_precision=4, quantity_precision=2)
DERC_USDT = Pair("DERC_USDT", price_precision=4, quantity_precision=2)
DGB_USDC = Pair("DGB_USDC", price_precision=6, quantity_precision=0)
DIA_USDT = Pair("DIA_USDT", price_precision=4, quantity_precision=2)
DOGE_BTC = Pair("DOGE_BTC", price_precision=10, quantity_precision=1)
DOGE_USDC = Pair("DOGE_USDC", price_precision=5, quantity_precision=1)
DOGE_USDT = Pair("DOGE_USDT", price_precision=5, quantity_precision=2)
DOT_BTC = Pair("DOT_BTC", price_precision=7, quantity_precision=4)
DOT_USDC = Pair("DOT_USDC", price_precision=3, quantity_precision=3)
DOT_USDT = Pair("DOT_USDT", price_precision=4, quantity_precision=3)
DYDX_BTC = Pair("DYDX_BTC", price_precision=8, quantity_precision=3)
DYDX_USDT = Pair("DYDX_USDT", price_precision=3, quantity_precision=3)
EFI_BTC = Pair("EFI_BTC", price_precision=9, quantity_precision=2)
EFI_USDT = Pair("EFI_USDT", price_precision=4, quantity_precision=2)
EGLD_BTC = Pair("EGLD_BTC", price_precision=7, quantity_precision=4)
EGLD_USDC = Pair("EGLD_USDC", price_precision=2, quantity_precision=4)
EGLD_USDT = Pair("EGLD_USDT", price_precision=4, quantity_precision=3)
ELON_USDC = Pair("ELON_USDC", price_precision=10, quantity_precision=0)
ELON_USDT = Pair("ELON_USDT", price_precision=10, quantity_precision=0)
ENJ_BTC = Pair("ENJ_BTC", price_precision=9, quantity_precision=2)
ENJ_USDC = Pair("ENJ_USDC", price_precision=4, quantity_precision=2)
ENJ_USDT = Pair("ENJ_USDT", price_precision=5, quantity_precision=1)
ENS_BTC = Pair("ENS_BTC", price_precision=8, quantity_precision=3)
ENS_USDC = Pair("ENS_USDC", price_precision=3, quantity_precision=3)
ENS_USDT = Pair("ENS_USDT", price_precision=3, quantity_precision=3)
EOS_BTC = Pair("EOS_BTC", price_precision=8, quantity_precision=2)
EOS_USDT = Pair("EOS_USDT", price_precision=4, quantity_precision=2)
ERN_USDT = Pair("ERN_USDT", price_precision=4, quantity_precision=2)
ETC_BTC = Pair("ETC_BTC", price_precision=7, quantity_precision=3)
ETC_USDT = Pair("ETC_USDT", price_precision=3, quantity_precision=3)
ETH_BTC = Pair("ETH_BTC", price_precision=6, quantity_precision=5)
ETH_CRO = Pair("ETH_CRO", price_precision=2, quantity_precision=5)
ETH_USDC = Pair("ETH_USDC", price_precision=2, quantity_precision=5)
ETH_USDT = Pair("ETH_USDT", price_precision=2, quantity_precision=5)
FARM_USDC = Pair("FARM_USDC", price_precision=2, quantity_precision=4)
FET_USDT = Pair("FET_USDT", price_precision=5, quantity_precision=1)
FIL_BTC = Pair("FIL_BTC", price_precision=7, quantity_precision=3)
FIL_USDT = Pair("FIL_USDT", price_precision=3, quantity_precision=3)
FITFI_BTC = Pair("FITFI_BTC", price_precision=9, quantity_precision=2)
FITFI_USDT = Pair("FITFI_USDT", price_precision=5, quantity_precision=1)
FLOW_BTC = Pair("FLOW_BTC", price_precision=8, quantity_precision=2)
FLOW_USDC = Pair("FLOW_USDC", price_precision=4, quantity_precision=2)
FLOW_USDT = Pair("FLOW_USDT", price_precision=3, quantity_precision=4)
FLUX_USDT = Pair("FLUX_USDT", price_precision=4, quantity_precision=2)
FORTH_USDT = Pair("FORTH_USDT", price_precision=3, quantity_precision=3)
FTM_BTC = Pair("FTM_BTC", price_precision=9, quantity_precision=2)
FTM_USDC = Pair("FTM_USDC", price_precision=4, quantity_precision=2)
FTM_USDT = Pair("FTM_USDT", price_precision=4, quantity_precision=2)
FXS_BTC = Pair("FXS_BTC", price_precision=8, quantity_precision=3)
FXS_USDC = Pair("FXS_USDC", price_precision=4, quantity_precision=2)
FXS_USDT = Pair("FXS_USDT", price_precision=3, quantity_precision=2)
GALA_BTC = Pair("GALA_BTC", price_precision=9, quantity_precision=1)
GALA_USDC = Pair("GALA_USDC", price_precision=5, quantity_precision=1)
GALA_USDT = Pair("GALA_USDT", price_precision=6, quantity_precision=0)
GHST_USDC = Pair("GHST_USDC", price_precision=4, quantity_precision=2)
GLMR_BTC = Pair("GLMR_BTC", price_precision=9, quantity_precision=2)
GLMR_USDT = Pair("GLMR_USDT", price_precision=4, quantity_precision=2)
GLM_USDT = Pair("GLM_USDT", price_precision=5, quantity_precision=1)
GODS_USDT = Pair("GODS_USDT", price_precision=4, quantity_precision=2)
GRT_BTC = Pair("GRT_BTC", price_precision=10, quantity_precision=1)
GRT_USDT = Pair("GRT_USDT", price_precision=5, quantity_precision=2)
GTC_USDT = Pair("GTC_USDT", price_precision=3, quantity_precision=3)
HBAR_BTC = Pair("HBAR_BTC", price_precision=10, quantity_precision=1)
HBAR_USDT = Pair("HBAR_USDT", price_precision=5, quantity_precision=1)
HERO_USDT = Pair("HERO_USDT", price_precision=6, quantity_precision=0)
HIGH_USDT = Pair("HIGH_USDT", price_precision=4, quantity_precision=2)
HNT_BTC = Pair("HNT_BTC", price_precision=8, quantity_precision=3)
HNT_USDC = Pair("HNT_USDC", price_precision=3, quantity_precision=3)
HNT_USDT = Pair("HNT_USDT", price_precision=3, quantity_precision=3)
HOD_USDT = Pair("HOD_USDT", price_precision=6, quantity_precision=0)
HOT_USDT = Pair("HOT_USDT", price_precision=6, quantity_precision=0)
ICP_BTC = Pair("ICP_BTC", price_precision=8, quantity_precision=3)
ICP_USDC = Pair("ICP_USDC", price_precision=3, quantity_precision=3)
ICP_USDT = Pair("ICP_USDT", price_precision=3, quantity_precision=3)
ICX_BTC = Pair("ICX_BTC", price_precision=8, quantity_precision=1)
ICX_USDT = Pair("ICX_USDT", price_precision=4, quantity_precision=2)
ILV_BTC = Pair("ILV_BTC", price_precision=6, quantity_precision=4)
ILV_USDT = Pair("ILV_USDT", price_precision=2, quantity_precision=4)
IMX_BTC = Pair("IMX_BTC", price_precision=9, quantity_precision=2)
IMX_USDC = Pair("IMX_USDC", price_precision=4, quantity_precision=2)
IMX_USDT = Pair("IMX_USDT", price_precision=4, quantity_precision=2)
INJ_USDC = Pair("INJ_USDC", price_precision=4, quantity_precision=2)
INJ_USDT = Pair("INJ_USDT", price_precision=3, quantity_precision=3)
IOTX_USDC = Pair("IOTX_USDC", price_precision=6, quantity_precision=0)
IOTX_USDT = Pair("IOTX_USDT", price_precision=5, quantity_precision=1)
IQ_USDT = Pair("IQ_USDT", price_precision=6, quantity_precision=0)
JASMY_BTC = Pair("JASMY_BTC", price_precision=10, quantity_precision=1)
JASMY_USDC = Pair("JASMY_USDC", price_precision=5, quantity_precision=1)
JASMY_USDT = Pair("JASMY_USDT", price_precision=5, quantity_precision=1)
JOE_USDT = Pair("JOE_USDT", price_precision=5, quantity_precision=1)
KAVA_USDT = Pair("KAVA_USDT", price_precision=4, quantity_precision=2)
KLAY_USDT = Pair("KLAY_USDT", price_precision=4, quantity_precision=2)
KNC_BTC = Pair("KNC_BTC", price_precision=9, quantity_precision=2)
KNC_USDT = Pair("KNC_USDT", price_precision=4, quantity_precision=3)
KP3R_USDT = Pair("KP3R_USDT", price_precision=2, quantity_precision=4)
KRL_USDT = Pair("KRL_USDT", price_precision=5, quantity_precision=1)
KSM_BTC = Pair("KSM_BTC", price_precision=7, quantity_precision=4)
KSM_USDC = Pair("KSM_USDC", price_precision=2, quantity_precision=4)
KSM_USDT = Pair("KSM_USDT", price_precision=3, quantity_precision=3)
LDO_BTC = Pair("LDO_BTC", price_precision=9, quantity_precision=2)
LDO_USDT = Pair("LDO_USDT", price_precision=4, quantity_precision=2)
LINK_BTC = Pair("LINK_BTC", price_precision=7, quantity_precision=2)
LINK_CRO = Pair("LINK_CRO", price_precision=2, quantity_precision=2)
LINK_USDC = Pair("LINK_USDC", price_precision=3, quantity_precision=3)
LINK_USDT = Pair("LINK_USDT", price_precision=3, quantity_precision=2)
LPT_USDC = Pair("LPT_USDC", price_precision=3, quantity_precision=3)
LRC_USDT = Pair("LRC_USDT", price_precision=5, quantity_precision=2)
LSK_USDT = Pair("LSK_USDT", price_precision=4, quantity_precision=2)
LTC_BTC = Pair("LTC_BTC", price_precision=6, quantity_precision=4)
LTC_USDC = Pair("LTC_USDC", price_precision=2, quantity_precision=4)
LTC_USDT = Pair("LTC_USDT", price_precision=2, quantity_precision=5)
MANA_BTC = Pair("MANA_BTC", price_precision=9, quantity_precision=1)
MANA_USDC = Pair("MANA_USDC", price_precision=4, quantity_precision=2)
MANA_USDT = Pair("MANA_USDT", price_precision=5, quantity_precision=2)
MASK_USDT = Pair("MASK_USDT", price_precision=4, quantity_precision=2)
MATIC_BTC = Pair("MATIC_BTC", price_precision=9, quantity_precision=0)
MATIC_USDC = Pair("MATIC_USDC", price_precision=5, quantity_precision=1)
MATIC_USDT = Pair("MATIC_USDT", price_precision=5, quantity_precision=2)
MBL_BTC = Pair("MBL_BTC", price_precision=10, quantity_precision=0)
MBL_USDT = Pair("MBL_USDT", price_precision=6, quantity_precision=0)
MC_USDT = Pair("MC_USDT", price_precision=4, quantity_precision=2)
MDT_USDT = Pair("MDT_USDT", price_precision=6, quantity_precision=0)
MKR_USDT = Pair("MKR_USDT", price_precision=2, quantity_precision=6)
MLN_USDC = Pair("MLN_USDC", price_precision=3, quantity_precision=3)
MMF_USDC = Pair("MMF_USDC", price_precision=4, quantity_precision=2)
MOVR_BTC = Pair("MOVR_BTC", price_precision=7, quantity_precision=4)
MOVR_USDT = Pair("MOVR_USDT", price_precision=2, quantity_precision=4)
MULTI_BTC = Pair("MULTI_BTC", price_precision=8, quantity_precision=3)
MULTI_USDT = Pair("MULTI_USDT", price_precision=3, quantity_precision=3)
MXC_USDT = Pair("MXC_USDT", price_precision=5, quantity_precision=1)
NEAR_BTC = Pair("NEAR_BTC", price_precision=8, quantity_precision=2)
NEAR_USDC = Pair("NEAR_USDC", price_precision=3, quantity_precision=3)
NEAR_USDT = Pair("NEAR_USDT", price_precision=4, quantity_precision=2)
NEO_BTC = Pair("NEO_BTC", price_precision=7, quantity_precision=3)
NEO_USDT = Pair("NEO_USDT", price_precision=3, quantity_precision=4)
NKN_USDT = Pair("NKN_USDT", price_precision=5, quantity_precision=1)
NMR_USDT = Pair("NMR_USDT", price_precision=3, quantity_precision=3)
OCEAN_USDT = Pair("OCEAN_USDT", price_precision=4, quantity_precision=2)
OGN_BTC = Pair("OGN_BTC", price_precision=9, quantity_precision=2)
OGN_USDT = Pair("OGN_USDT", price_precision=4, quantity_precision=2)
OMG_BTC = Pair("OMG_BTC", price_precision=8, quantity_precision=4)
OMG_USDT = Pair("OMG_USDT", price_precision=4, quantity_precision=4)
ONEINCH_BTC = Pair("1INCH_BTC", price_precision=9, quantity_precision=2)
ONEINCH_USDC = Pair("1INCH_USDC", price_precision=4, quantity_precision=2)
ONEINCH_USDT = Pair("1INCH_USDT", price_precision=4, quantity_precision=2)
ONE_BTC = Pair("ONE_BTC", price_precision=10, quantity_precision=1)
ONE_USDC = Pair("ONE_USDC", price_precision=5, quantity_precision=1)
ONE_USDT = Pair("ONE_USDT", price_precision=5, quantity_precision=1)
ONT_BTC = Pair("ONT_BTC", price_precision=8, quantity_precision=2)
ONT_USDT = Pair("ONT_USDT", price_precision=4, quantity_precision=2)
OXT_USDT = Pair("OXT_USDT", price_precision=5, quantity_precision=1)
PAXG_USDT = Pair("PAXG_USDT", price_precision=2, quantity_precision=5)
PENDLE_USDT = Pair("PENDLE_USDT", price_precision=5, quantity_precision=1)
PERP_USDT = Pair("PERP_USDT", price_precision=3, quantity_precision=3)
PLA_USDT = Pair("PLA_USDT", price_precision=5, quantity_precision=1)
POLS_USDT = Pair("POLS_USDT", price_precision=4, quantity_precision=2)
POLY_USDC = Pair("POLY_USDC", price_precision=5, quantity_precision=1)
POWR_USDT = Pair("POWR_USDT", price_precision=5, quantity_precision=1)
PRQ_BTC = Pair("PRQ_BTC", price_precision=10, quantity_precision=1)
PRQ_USDT = Pair("PRQ_USDT", price_precision=5, quantity_precision=1)
PYR_BTC = Pair("PYR_BTC", price_precision=8, quantity_precision=3)
PYR_USDC = Pair("PYR_USDC", price_precision=3, quantity_precision=3)
PYR_USDT = Pair("PYR_USDT", price_precision=3, quantity_precision=3)
QI_USDT = Pair("QI_USDT", price_precision=5, quantity_precision=1)
QNT_USDC = Pair("QNT_USDC", price_precision=2, quantity_precision=4)
QNT_USDT = Pair("QNT_USDT", price_precision=2, quantity_precision=4)
QRDO_USDT = Pair("QRDO_USDT", price_precision=4, quantity_precision=2)
QTUM_USDT = Pair("QTUM_USDT", price_precision=4, quantity_precision=4)
QUICK_USDT = Pair("QUICK_USDT", price_precision=2, quantity_precision=4)
RADAR_BTC = Pair("RADAR_BTC", price_precision=10, quantity_precision=0)
RADAR_USDT = Pair("RADAR_USDT", price_precision=6, quantity_precision=0)
RAD_USDC = Pair("RAD_USDC", price_precision=3, quantity_precision=3)
RARE_USDT = Pair("RARE_USDT", price_precision=5, quantity_precision=1)
RARI_USDC = Pair("RARI_USDC", price_precision=3, quantity_precision=3)
RARI_USDT = Pair("RARI_USDT", price_precision=3, quantity_precision=3)
RAY_USDT = Pair("RAY_USDT", price_precision=4, quantity_precision=2)
REEF_USDT = Pair("REEF_USDT", price_precision=7, quantity_precision=0)
REN_USDT = Pair("REN_USDT", price_precision=5, quantity_precision=2)
REQ_USDT = Pair("REQ_USDT", price_precision=5, quantity_precision=1)
RLC_USDT = Pair("RLC_USDT", price_precision=3, quantity_precision=3)
RLY_USDT = Pair("RLY_USDT", price_precision=5, quantity_precision=2)
RNDR_USDT = Pair("RNDR_USDT", price_precision=4, quantity_precision=2)
RSR_USDT = Pair("RSR_USDT", price_precision=5, quantity_precision=1)
RUNE_BTC = Pair("RUNE_BTC", price_precision=8, quantity_precision=3)
RUNE_USDT = Pair("RUNE_USDT", price_precision=3, quantity_precision=3)
SAND_BTC = Pair("SAND_BTC", price_precision=8, quantity_precision=2)
SAND_USDC = Pair("SAND_USDC", price_precision=4, quantity_precision=2)
SAND_USDT = Pair("SAND_USDT", price_precision=5, quantity_precision=2)
SC_USDT = Pair("SC_USDT", price_precision=6, quantity_precision=0)
SDN_USDC = Pair("SDN_USDC", price_precision=4, quantity_precision=2)
SDN_USDT = Pair("SDN_USDT", price_precision=4, quantity_precision=2)
SHIB_USDC = Pair("SHIB_USDC", price_precision=9, quantity_precision=0)
SHIB_USDT = Pair("SHIB_USDT", price_precision=9, quantity_precision=0)
SKL_BTC = Pair("SKL_BTC", price_precision=10, quantity_precision=1)
SKL_USDT = Pair("SKL_USDT", price_precision=5, quantity_precision=2)
SLP_BTC = Pair("SLP_BTC", price_precision=10, quantity_precision=0)
SLP_USDC = Pair("SLP_USDC", price_precision=6, quantity_precision=0)
SLP_USDT = Pair("SLP_USDT", price_precision=5, quantity_precision=1)
SNT_USDT = Pair("SNT_USDT", price_precision=6, quantity_precision=0)
SNX_USDT = Pair("SNX_USDT", price_precision=3, quantity_precision=3)
SOL_BTC = Pair("SOL_BTC", price_precision=7, quantity_precision=3)
SOL_USDC = Pair("SOL_USDC", price_precision=3, quantity_precision=3)
SOL_USDT = Pair("SOL_USDT", price_precision=3, quantity_precision=3)
SPELL_USDC = Pair("SPELL_USDC", price_precision=6, quantity_precision=0)
SPELL_USDT = Pair("SPELL_USDT", price_precision=7, quantity_precision=0)
SPS_USDT = Pair("SPS_USDT", price_precision=5, quantity_precision=1)
SRM_USDC = Pair("SRM_USDC", price_precision=4, quantity_precision=2)
SRM_USDT = Pair("SRM_USDT", price_precision=4, quantity_precision=2)
STORJ_USDT = Pair("STORJ_USDT", price_precision=4, quantity_precision=2)
STRAX_USDT = Pair("STRAX_USDT", price_precision=4, quantity_precision=2)
STX_BTC = Pair("STX_BTC", price_precision=9, quantity_precision=2)
STX_USDC = Pair("STX_USDC", price_precision=4, quantity_precision=2)
STX_USDT = Pair("STX_USDT", price_precision=4, quantity_precision=2)
SUPER_USDT = Pair("SUPER_USDT", price_precision=4, quantity_precision=2)
SUSHI_BTC = Pair("SUSHI_BTC", price_precision=8, quantity_precision=2)
SUSHI_USDT = Pair("SUSHI_USDT", price_precision=3, quantity_precision=3)
TFUEL_USDT = Pair("TFUEL_USDT", price_precision=5, quantity_precision=1)
THETA_USDC = Pair("THETA_USDC", price_precision=4, quantity_precision=2)
THETA_USDT = Pair("THETA_USDT", price_precision=4, quantity_precision=2)
TONIC_USDC = Pair("TONIC_USDC", price_precision=10, quantity_precision=0)
TONIC_USDT = Pair("TONIC_USDT", price_precision=10, quantity_precision=0)
TRB_USDT = Pair("TRB_USDT", price_precision=3, quantity_precision=3)
TRIBE_USDT = Pair("TRIBE_USDT", price_precision=4, quantity_precision=2)
TRU_USDT = Pair("TRU_USDT", price_precision=5, quantity_precision=1)
TUSD_USDT = Pair("TUSD_USDT", price_precision=5, quantity_precision=1)
T_USDT = Pair("T_USDT", price_precision=5, quantity_precision=1)
UMA_USDT = Pair("UMA_USDT", price_precision=3, quantity_precision=4)
UNI_BTC = Pair("UNI_BTC", price_precision=8, quantity_precision=3)
UNI_USDC = Pair("UNI_USDC", price_precision=3, quantity_precision=3)
UNI_USDT = Pair("UNI_USDT", price_precision=4, quantity_precision=4)
USDC_USDT = Pair("USDC_USDT", price_precision=4, quantity_precision=2)
VET_BTC = Pair("VET_BTC", price_precision=10, quantity_precision=0)
VET_USDC = Pair("VET_USDC", price_precision=6, quantity_precision=0)
VET_USDT = Pair("VET_USDT", price_precision=6, quantity_precision=0)
VOXEL_USDT = Pair("VOXEL_USDT", price_precision=4, quantity_precision=2)
VRA_USDT = Pair("VRA_USDT", price_precision=6, quantity_precision=0)
VTHO_USDT = Pair("VTHO_USDT", price_precision=6, quantity_precision=0)
VVS_USDC = Pair("VVS_USDC", price_precision=8, quantity_precision=0)
VVS_USDT = Pair("VVS_USDT", price_precision=8, quantity_precision=0)
WAVES_BTC = Pair("WAVES_BTC", price_precision=8, quantity_precision=3)
WAVES_USDT = Pair("WAVES_USDT", price_precision=3, quantity_precision=3)
WAXP_USDT = Pair("WAXP_USDT", price_precision=5, quantity_precision=1)
WBTC_BTC = Pair("WBTC_BTC", price_precision=4, quantity_precision=6)
WBTC_USDC = Pair("WBTC_USDC", price_precision=2, quantity_precision=6)
WBTC_USDT = Pair("WBTC_USDT", price_precision=2, quantity_precision=6)
WEMIX_USDT = Pair("WEMIX_USDT", price_precision=4, quantity_precision=2)
WOO_USDT = Pair("WOO_USDT", price_precision=5, quantity_precision=1)
XLM_BTC = Pair("XLM_BTC", price_precision=9, quantity_precision=0)
XLM_USDC = Pair("XLM_USDC", price_precision=5, quantity_precision=1)
XLM_USDT = Pair("XLM_USDT", price_precision=5, quantity_precision=1)
XRP_BTC = Pair("XRP_BTC", price_precision=9, quantity_precision=0)
XRP_USDC = Pair("XRP_USDC", price_precision=5, quantity_precision=1)
XRP_USDT = Pair("XRP_USDT", price_precision=5, quantity_precision=1)
XTZ_BTC = Pair("XTZ_BTC", price_precision=8, quantity_precision=2)
XTZ_USDT = Pair("XTZ_USDT", price_precision=4, quantity_precision=2)
XYO_USDC = Pair("XYO_USDC", price_precision=6, quantity_precision=0)
XYO_USDT = Pair("XYO_USDT", price_precision=6, quantity_precision=0)
YFI_BTC = Pair("YFI_BTC", price_precision=4, quantity_precision=6)
YFI_USDT = Pair("YFI_USDT", price_precision=2, quantity_precision=6)
YGG_BTC = Pair("YGG_BTC", price_precision=8, quantity_precision=2)
YGG_USDT = Pair("YGG_USDT", price_precision=4, quantity_precision=2)
ZBC_USDT = Pair("ZBC_USDT", price_precision=6, quantity_precision=0)
ZIL_BTC = Pair("ZIL_BTC", price_precision=10, quantity_precision=1)
ZIL_USDT = Pair("ZIL_USDT", price_precision=5, quantity_precision=1)
ZRX_USDT = Pair("ZRX_USDT", price_precision=4, quantity_precision=2)


def all():
    return [
        value for name, value in globals().items() if isinstance(value, Pair)
    ]
