from .structs import Coin

AAVE = Coin("AAVE")
ACA = Coin("ACA")
ADA = Coin("ADA")
AERGO = Coin("AERGO")
AGLD = Coin("AGLD")
AKT = Coin("AKT")
ALGO = Coin("ALGO")
ALI = Coin("ALI")
ALICE = Coin("ALICE")
ALPHA = Coin("ALPHA")
AMP = Coin("AMP")
ANC = Coin("ANC")
ANKR = Coin("ANKR")
ANY = Coin("ANY")
APE = Coin("APE")
API3 = Coin("API3")
AR = Coin("AR")
ARPA = Coin("ARPA")
ATOM = Coin("ATOM")
AUDIO = Coin("AUDIO")
AURORA = Coin("AURORA")
AUTO = Coin("AUTO")
AVAX = Coin("AVAX")
AXS = Coin("AXS")
BADGER = Coin("BADGER")
BAL = Coin("BAL")
BAND = Coin("BAND")
BAT = Coin("BAT")
BCH = Coin("BCH")
BICO = Coin("BICO")
BIFI = Coin("BIFI")
BNT = Coin("BNT")
BOBA = Coin("BOBA")
BOND = Coin("BOND")
BOSON = Coin("BOSON")
BRZ = Coin("BRZ")
BTC = Coin("BTC")
BUSD = Coin("BUSD")
C98 = Coin("C98")
CELR = Coin("CELR")
CHR = Coin("CHR")
CHZ = Coin("CHZ")
CKB = Coin("CKB")
COMP = Coin("COMP")
COTI = Coin("COTI")
CQT = Coin("CQT")
CRO = Coin("CRO")
CRPT = Coin("CRPT")
CRV = Coin("CRV")
CSPR = Coin("CSPR")
CTSI = Coin("CTSI")
CVX = Coin("CVX")
DAI = Coin("DAI")
DAR = Coin("DAR")
DERC = Coin("DERC")
DGB = Coin("DGB")
DIA = Coin("DIA")
DINO = Coin("DINO")
DOGE = Coin("DOGE")
DOT = Coin("DOT")
DYDX = Coin("DYDX")
EFI = Coin("EFI")
EGLD = Coin("EGLD")
ELON = Coin("ELON")
ENJ = Coin("ENJ")
ENS = Coin("ENS")
EOS = Coin("EOS")
EPS = Coin("EPS")
ERN = Coin("ERN")
ETC = Coin("ETC")
ETH = Coin("ETH")
FARM = Coin("FARM")
FET = Coin("FET")
FIL = Coin("FIL")
FITFI = Coin("FITFI")
FLOW = Coin("FLOW")
FLUX = Coin("FLUX")
FORTH = Coin("FORTH")
FTM = Coin("FTM")
FXS = Coin("FXS")
GALA = Coin("GALA")
GHST = Coin("GHST")
GLM = Coin("GLM")
GLMR = Coin("GLMR")
GMT = Coin("GMT")
GODS = Coin("GODS")
GRT = Coin("GRT")
GTC = Coin("GTC")
GUSD = Coin("GUSD")
HBAR = Coin("HBAR")
HERO = Coin("HERO")
HIGH = Coin("HIGH")
HNT = Coin("HNT")
HOD = Coin("HOD")
HOT = Coin("HOT")
HUSD = Coin("HUSD")
ICP = Coin("ICP")
ICX = Coin("ICX")
ILV = Coin("ILV")
IMX = Coin("IMX")
INJ = Coin("INJ")
IOTX = Coin("IOTX")
IQ = Coin("IQ")
JASMY = Coin("JASMY")
JOE = Coin("JOE")
KAVA = Coin("KAVA")
KEEP = Coin("KEEP")
KLAY = Coin("KLAY")
KNC = Coin("KNC")
KP3R = Coin("KP3R")
KRL = Coin("KRL")
KSM = Coin("KSM")
LDO = Coin("LDO")
LINK = Coin("LINK")
LPT = Coin("LPT")
LRC = Coin("LRC")
LSK = Coin("LSK")
LTC = Coin("LTC")
LUNA = Coin("LUNA")
LUNC = Coin("LUNC")
MANA = Coin("MANA")
MASK = Coin("MASK")
MATIC = Coin("MATIC")
MBL = Coin("MBL")
MC = Coin("MC")
MCO = Coin("MCO")
MDT = Coin("MDT")
MIR = Coin("MIR")
MKR = Coin("MKR")
MLN = Coin("MLN")
MMF = Coin("MMF")
MOVR = Coin("MOVR")
MULTI = Coin("MULTI")
MXC = Coin("MXC")
NANO = Coin("NANO")
NEAR = Coin("NEAR")
NEO = Coin("NEO")
NKN = Coin("NKN")
NMR = Coin("NMR")
NU = Coin("NU")
OCEAN = Coin("OCEAN")
OGN = Coin("OGN")
OMG = Coin("OMG")
ONE = Coin("ONE")
ONEINCH = Coin("1INCH")
ONT = Coin("ONT")
OXT = Coin("OXT")
PAX = Coin("PAX")
PAXG = Coin("PAXG")
PENDLE = Coin("PENDLE")
PERP = Coin("PERP")
PLA = Coin("PLA")
POLS = Coin("POLS")
POLY = Coin("POLY")
POWR = Coin("POWR")
PRQ = Coin("PRQ")
PYR = Coin("PYR")
QI = Coin("QI")
QNT = Coin("QNT")
QRDO = Coin("QRDO")
QTUM = Coin("QTUM")
QUICK = Coin("QUICK")
RAD = Coin("RAD")
RADAR = Coin("RADAR")
RARE = Coin("RARE")
RARI = Coin("RARI")
RAY = Coin("RAY")
REEF = Coin("REEF")
REN = Coin("REN")
REQ = Coin("REQ")
RGT = Coin("RGT")
RLC = Coin("RLC")
RLY = Coin("RLY")
RNDR = Coin("RNDR")
RSR = Coin("RSR")
RUNE = Coin("RUNE")
RVN = Coin("RVN")
SAND = Coin("SAND")
SC = Coin("SC")
SDN = Coin("SDN")
SGB = Coin("SGB")
SHIB = Coin("SHIB")
SKL = Coin("SKL")
SLP = Coin("SLP")
SNT = Coin("SNT")
SNX = Coin("SNX")
SOL = Coin("SOL")
SPELL = Coin("SPELL")
SPS = Coin("SPS")
SRM = Coin("SRM")
STORJ = Coin("STORJ")
STRAX = Coin("STRAX")
STX = Coin("STX")
SUPER = Coin("SUPER")
SUSHI = Coin("SUSHI")
T = Coin("T")
TFUEL = Coin("TFUEL")
THETA = Coin("THETA")
TONIC = Coin("TONIC")
TRB = Coin("TRB")
TRIBE = Coin("TRIBE")
TRU = Coin("TRU")
TUSD = Coin("TUSD")
UMA = Coin("UMA")
UNI = Coin("UNI")
USDC = Coin("USDC")
USDP = Coin("USDP")
USDT = Coin("USDT")
VET = Coin("VET")
VOXEL = Coin("VOXEL")
VRA = Coin("VRA")
VTHO = Coin("VTHO")
VVS = Coin("VVS")
WAVE = Coin("WAVE")
WAVES = Coin("WAVES")
WAXP = Coin("WAXP")
WBTC = Coin("WBTC")
WEMIX = Coin("WEMIX")
WOO = Coin("WOO")
XLM = Coin("XLM")
XRP = Coin("XRP")
XTZ = Coin("XTZ")
XYO = Coin("XYO")
YFI = Coin("YFI")
YGG = Coin("YGG")
ZBC = Coin("ZBC")
ZIL = Coin("ZIL")
ZRX = Coin("ZRX")


def all():
    return [
        value for name, value in globals().items() if isinstance(value, Coin)
    ]
